@@ -1,8 +1,8 @@
 (* camlp5r pa_macro.cmo pa_extend.cmo *)
-(* $Id: pcaml.ml 1900 2008-02-20 10:59:00Z deraugla $ *)
+(* $Id: pcaml.ml 1927 2009-05-23 09:04:13Z deraugla $ *)
 (* Copyright (c) INRIA 2007-2008 *)
 
-value version = "5.08";
+value version = "5.12";
 value syntax_name = ref "";
 
 value gram =
@@ -30,6 +30,8 @@ value type_declaration = Grammar.Entry.create gram "type_declaration";
 value match_case = Grammar.Entry.create gram "match_case";
 value constructor_declaration =
   Grammar.Entry.create gram "constructor_declaration";
+value label_declaration =
+  Grammar.Entry.create gram "label_declaration";
 value with_constr = Grammar.Entry.create gram "with_constr";
 value poly_variant = Grammar.Entry.create gram "poly_variant";
 
