@@ -1,5 +1,6 @@
-#!/bin/bash -e
-if test "$(basename "$(dirname $OTOP)")" != "ocaml_stuff"; then
+#!/bin/sh -e
+dir=`dirname $OTOP`
+if test "`basename $dir`" != "ocaml_stuff"; then
     COMM="$OTOP/boot/ocamlrun$EXE $OTOP/ocamlopt -I $OTOP/stdlib"
 else
     COMM=ocamlopt$OPT
